@@ -1,11 +1,10 @@
 #!perl
-
 use 5.008001; use utf8; use strict; use warnings;
 
 package Rosetta::Validator;
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
-use Rosetta '0.42';
+use Rosetta 0.43;
 
 ######################################################################
 
@@ -23,7 +22,7 @@ Core Modules: I<none>
 
 Non-Core Modules: 
 
-	Rosetta 0.42
+	Rosetta 0.43
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -339,7 +338,130 @@ __END__
 
 =head1 SYNOPSIS
 
-I<The previous SYNOPSIS was removed; a new one will be written later.>
+This example demonstrates how Rosetta::Validator could be used in the standard
+test suite for an Engine module; in fact, this example is a simplified version
+of the actual t/*.t file for the Rosetta::Engine::Generic module.
+
+This is the content of a t_setup.pl, for a SQLite database:
+
+	my $setup_options = {
+		'data_storage_product' => {
+			'product_code' => 'SQLite',
+			'is_file_based' => 1,
+		},
+		'data_link_product' => {
+			'product_code' => 'Rosetta::Engine::Generic',
+		},
+		'catalog_instance' => {
+			'file_path' => 'test',
+		},
+	};
+
+This is the content of a t_setup.pl, for a MySQL database:
+
+	my $setup_options = {
+		'data_storage_product' => {
+			'product_code' => 'MySQL',
+			'is_network_svc' => 1,
+		},
+		'data_link_product' => {
+			'product_code' => 'Rosetta::Engine::Generic',
+		},
+		'catalog_link_instance' => {
+			'local_dsn' => 'test',
+			'login_name' => 'jane',
+			'login_pass' => 'pwd',
+		},
+	};
+
+This is a generalized version of Rosetta_Engine_Generic.t:
+
+	#!perl
+	use 5.008001; use utf8; use strict; use warnings;
+
+	use Test::More;
+	use Rosetta::Validator;
+
+	plan( 'tests' => Rosetta::Validator->total_possible_tests() );
+
+	sub print_result {
+		my ($result) = @_;
+		my ($feature_key, $feature_status, $feature_desc_msg, $val_error_msg, $eng_error_msg) = 
+			@{$result}{'FEATURE_KEY', 'FEATURE_STATUS', 'FEATURE_DESC_MSG', 'VAL_ERROR_MSG', 'ENG_ERROR_MSG'};
+		my $result_str = 
+			$feature_key.' - '.object_to_string( $feature_desc_msg ).
+			($val_error_msg ? ' - '.object_to_string( $val_error_msg ) : '').
+			($eng_error_msg ? ' - '.object_to_string( $eng_error_msg ) : '');
+		if( $feature_status eq 'PASS' ) {
+			pass( $result_str ); # prints "ok N - $result_str\n"
+		} elsif( $feature_status eq 'FAIL' ) {
+			fail( $result_str ); # prints "not ok N - $result_str\n"
+		} else { # $feature_status eq 'SKIP'
+			SKIP: {
+				skip( $result_str, 1 ); # prints "ok N # skip $result_str\n"
+				fail( '' ); # this text will NOT be output; call required by skip()
+			}
+		}
+	}
+
+	sub object_to_string {
+		my ($message) = @_;
+		if( ref($message) and UNIVERSAL::isa( $message, 'Rosetta::Interface' ) ) {
+			$message = $message->get_error_message();
+		}
+		if( ref($message) and UNIVERSAL::isa( $message, 'Locale::KeyedText::Message' ) ) {
+			my $translator = Locale::KeyedText->new_translator( ['Rosetta::Engine::Generic::L::', 
+				'Rosetta::Validator::L::', 'Rosetta::L::', 'SQL::Routine::L::'], ['en'] );
+			my $user_text = $translator->translate_message( $message );
+			unless( $user_text ) {
+				return 'internal error: can\'t find user text for a message: '.
+					$message->as_string().' '.$translator->as_string();
+			}
+			return $user_text;
+		}
+		return $message; # if this isn't the right kind of object
+	}
+
+	sub import_setup_options {
+		my ($setup_filepath) = @_;
+		my $err_str = "can't obtain test setup specs from Perl file '".$setup_filepath."'; ";
+		my $setup_options = do $setup_filepath;
+		unless( ref($setup_options) eq 'HASH' ) {
+			if( defined( $setup_options ) ) {
+				$err_str .= "result is not a hash ref, but '$setup_options'";
+			} elsif( $@ ) {
+				$err_str .= "compilation or runtime error of '$@'";
+			} else {
+				$err_str .= "file system error of '$!'";
+			}
+			die "$err_str\n";
+		}
+		unless( scalar( keys %{$setup_options} ) ) {
+			die $err_str."result is a hash ref that contains no elements\n";
+		}
+		eval {
+			Rosetta->validate_connection_setup_options( $setup_options ); # dies on problem
+		};
+		if( my $exception = $@ ) {
+			die $err_str."result is a hash ref having invalid elements; ".
+				object_to_string( $exception )."\n";
+		}
+		return $setup_options;
+	}
+
+	my $setup_filepath = shift( @ARGV ) || 't_setup.pl'; # set from first command line arg; '0' means use default name
+	my $trace_to_stdout = shift( @ARGV ) ? 1 : 0; # set from second command line arg
+
+	my $setup_options = import_setup_options( $setup_filepath ); # dies if bad config file
+	my $trace_fh = $trace_to_stdout ? \*STDOUT : undef;
+
+	my $test_results = Rosetta::Validator->main( $setup_options, $trace_fh ); # shouldn't ever die
+
+	foreach my $result (@{$test_results}) {
+		print_result( $result );
+	}
+
+	1;
 
 =head1 DESCRIPTION
 
